pub enum Error {
StartTimeAheadOfCurrentTime(DateTime<Utc>),
MachineIdFailed(Box<dyn Error + Send + Sync + 'static>),
InvalidMachineID(u16),
TimeOverflow,
NoPrivateIPv4Address,
}Expand description
The Error type for this crate.
Variants
StartTimeAheadOfCurrentTime(DateTime<Utc>)
Error::StartTimeAheadOfCurrentTime means that start time is ahead of current time
MachineIdFailed(Box<dyn Error + Send + Sync + 'static>)
Error::MachineIdFailed returned by MachineID
InvalidMachineID(u16)
Error::InvalidMachineID returned by MachineIDChecker
TimeOverflow
Error::TimeOverflow means that we over the sonyflake time limit
NoPrivateIPv4Address
Error::NoPrivateIPv4Address means that there is no private ip address on this machine